Documentation
¶
Index ¶
- Constants
- type BlobStore
- func (cmd BlobStore) GetFlagValueBlobIds(blobStoreId *blob_store_id.Id) interfaces.FlagValue
- func (cmd *BlobStore) MakeBlobStoreFromIdOrConfigPath(envBlobStore env_repo.BlobStoreEnv, basePath string, ...) (blobStore blob_stores.BlobStoreInitialized)
- func (cmd *BlobStore) MakeBlobStoreFromIdString(envBlobStore env_repo.BlobStoreEnv, blobStoreIdString string) (blobStore blob_stores.BlobStoreInitialized)
- type Checkout
- type Complete
- func (cmd Complete) CompleteObjects(req command.Request, local *local_working_copy.Repo, ...)
- func (cmd Complete) CompleteObjectsIncludingWorkspace(req command.Request, local *local_working_copy.Repo, ...)
- func (cmd Complete) GetFlagValueMetadataTags(metadata objects.MetadataMutable) interfaces.FlagValue
- func (cmd Complete) GetFlagValueMetadataType(metadata objects.MetadataMutable) interfaces.FlagValue
- func (cmd Complete) GetFlagValueStringTags(value *values.String) interfaces.FlagValue
- func (cmd Complete) SetFlagsProto(proto *sku.Proto, flagSet interfaces.CLIFlagDefinitions, ...)
- type Env
- type EnvRepo
- type Genesis
- type InventoryLists
- type LocalWorkingCopy
- func (cmd LocalWorkingCopy) MakeLocalWorkingCopy(req command.Request) *local_working_copy.Repo
- func (cmd LocalWorkingCopy) MakeLocalWorkingCopyFromConfigAndXDGDotenvPath(req command.Request, xdgDotenvPath string, options env_ui.Options) (local *local_working_copy.Repo)
- func (cmd LocalWorkingCopy) MakeLocalWorkingCopyFromEnvLocal(envLocal env_local.Env) (local *local_working_copy.Repo)
- func (cmd LocalWorkingCopy) MakeLocalWorkingCopyWithOptions(req command.Request, envOptions env_ui.Options, ...) *local_working_copy.Repo
- func (cmd *LocalWorkingCopy) SetFlagDefinitions(f interfaces.CLIFlagDefinitions)
- type LocalWorkingCopyWithQueryGroup
- func (cmd LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroup(req command.Request, builderOptions queries.BuilderOption) (*local_working_copy.Repo, *queries.Query)
- func (cmd LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroupResolvingFilenames(req command.Request, builderOptions queries.BuilderOption) (*local_working_copy.Repo, *queries.Query)
- func (cmd *LocalWorkingCopyWithQueryGroup) SetFlagDefinitions(f interfaces.CLIFlagDefinitions)
- type ObjectMetadata
- func (cmd ObjectMetadata) GetFlagValueMetadataDescription(metadata objects.MetadataMutable) interfaces.FlagValue
- func (cmd ObjectMetadata) GetFlagValueMetadataTags(metadata objects.MetadataMutable) interfaces.FlagValue
- func (cmd ObjectMetadata) GetFlagValueMetadataType(metadata objects.MetadataMutable) interfaces.FlagValue
- type Query
- func (cmd Query) GetArgGroup() command.ArgGroup
- func (cmd Query) MakeQuery(req command.Request, options pkg_query.BuilderOption, workingCopy repo.Repo, ...) (query *pkg_query.Query)
- func (cmd Query) MakeQueryIncludingWorkspace(req command.Request, options pkg_query.BuilderOption, ...) (query *pkg_query.Query)
- func (cmd Query) MakeQueryResolvingFilenames(req command.Request, options pkg_query.BuilderOption, ...) (query *pkg_query.Query)
- func (cmd *Query) SetFlagDefinitions(flagSet interfaces.CLIFlagDefinitions)
- type Remote
- func (cmd Remote) IsDirectTransfer() bool
- func (cmd Remote) IsHomeRepoParent() bool
- func (cmd Remote) MakeDirectRemoteFromPath(req command.Request, local *local_working_copy.Repo) repo.Repo
- func (cmd Remote) MakeHomeRepoRemote(req command.Request) repo.Repo
- func (cmd Remote) MakeRemote(req command.Request, repo *local_working_copy.Repo, object *sku.Transacted) (remote repo.Repo)
- func (cmd Remote) MakeRemoteAndObject(req command.Request, local *local_working_copy.Repo) (remote repo.Repo, remoteObject *sku.Transacted)
- func (cmd Remote) MakeRemoteFromBlob(req command.Request, repo *local_working_copy.Repo, blob repo_blobs.Blob) (remote repo.Repo)
- func (cmd Remote) MakeRemoteFromBlobAndSetPublicKey(req command.Request, repo *local_working_copy.Repo, ...) (remote repo.Repo)
- func (cmd *Remote) MakeRemoteHTTPFromXDGDotenvPath(req command.Request, xdgDotenvPath string, options env_ui.Options, ...) (remoteHTTP repo.Repo)
- func (cmd *Remote) MakeRemoteStdioLocal(req command.Request, env env_local.Env, dir string, ...) (remoteHTTP repo.Repo)
- func (cmd *Remote) MakeRemoteStdioSSH(req command.Request, env env_local.Env, arg string, ...) (remoteHTTP repo.Repo)
- func (cmd *Remote) MakeRemoteUrl(req command.Request, env env_local.Env, uri values.Uri, ...) (remoteHTTP repo.Repo)
- func (cmd *Remote) ResolveImplicitDirectPath(local *local_working_copy.Repo)
- func (cmd *Remote) SetFlagDefinitions(flagSet interfaces.CLIFlagDefinitions)
- type RemoteRepoBlobs
- type RemoteTransfer
Constants ¶
const XDGUtilityNameMadder = "madder"
XDGUtilityNameMadder is the literal scope segment for madder's XDG namespace. Used as the second-env scope in env_repo.Make's two-env composition.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlobStore ¶
type BlobStore struct{}
func (BlobStore) GetFlagValueBlobIds ¶
func (cmd BlobStore) GetFlagValueBlobIds( blobStoreId *blob_store_id.Id, ) interfaces.FlagValue
func (*BlobStore) MakeBlobStoreFromIdOrConfigPath ¶
func (cmd *BlobStore) MakeBlobStoreFromIdOrConfigPath( envBlobStore env_repo.BlobStoreEnv, basePath string, blobStoreIndexOrConfigPath string, ) (blobStore blob_stores.BlobStoreInitialized)
func (*BlobStore) MakeBlobStoreFromIdString ¶
func (cmd *BlobStore) MakeBlobStoreFromIdString( envBlobStore env_repo.BlobStoreEnv, blobStoreIdString string, ) (blobStore blob_stores.BlobStoreInitialized)
type Checkout ¶
func (*Checkout) SetFlagDefinitions ¶
func (c *Checkout) SetFlagDefinitions(f interfaces.CLIFlagDefinitions)
type Complete ¶
type Complete struct {
ObjectMetadata
Query
}
func (Complete) CompleteObjects ¶
func (cmd Complete) CompleteObjects( req command.Request, local *local_working_copy.Repo, queryBuilderOptions pkg_query.BuilderOption, args ...string, )
func (Complete) CompleteObjectsIncludingWorkspace ¶
func (cmd Complete) CompleteObjectsIncludingWorkspace( req command.Request, local *local_working_copy.Repo, queryBuilderOptions pkg_query.BuilderOption, args ...string, )
func (Complete) GetFlagValueMetadataTags ¶
func (cmd Complete) GetFlagValueMetadataTags( metadata objects.MetadataMutable, ) interfaces.FlagValue
func (Complete) GetFlagValueMetadataType ¶
func (cmd Complete) GetFlagValueMetadataType( metadata objects.MetadataMutable, ) interfaces.FlagValue
func (Complete) GetFlagValueStringTags ¶
func (cmd Complete) GetFlagValueStringTags( value *values.String, ) interfaces.FlagValue
func (Complete) SetFlagsProto ¶
func (cmd Complete) SetFlagsProto( proto *sku.Proto, flagSet interfaces.CLIFlagDefinitions, descriptionUsage string, tagUsage string, typeUsage string, )
type Genesis ¶
type Genesis struct {
env_repo.BigBang
LocalWorkingCopy
BlobStore
}
func (Genesis) OnTheFirstDay ¶
func (*Genesis) SetFlagDefinitions ¶
func (cmd *Genesis) SetFlagDefinitions( flagSet interfaces.CLIFlagDefinitions, )
type InventoryLists ¶
type InventoryLists struct{}
func (InventoryLists) MakeInventoryListCoderCloset ¶
func (InventoryLists) MakeInventoryListCoderCloset( envRepo env_repo.Env, ) inventory_list_coders.Closet
func (InventoryLists) MakeSeqFromPath ¶
func (InventoryLists) MakeSeqFromPath( ctx interfaces.ActiveContext, inventoryListCoderCloset inventory_list_coders.Closet, inventoryListPath string, afterDecoding func(*sku.Transacted) error, ) interfaces.SeqError[*sku.Transacted]
type LocalWorkingCopy ¶
type LocalWorkingCopy struct {
command_components.Env
}
func (LocalWorkingCopy) MakeLocalWorkingCopy ¶
func (cmd LocalWorkingCopy) MakeLocalWorkingCopy( req command.Request, ) *local_working_copy.Repo
func (LocalWorkingCopy) MakeLocalWorkingCopyFromConfigAndXDGDotenvPath ¶
func (cmd LocalWorkingCopy) MakeLocalWorkingCopyFromConfigAndXDGDotenvPath( req command.Request, xdgDotenvPath string, options env_ui.Options, ) (local *local_working_copy.Repo)
TODO modify to work with archives
func (LocalWorkingCopy) MakeLocalWorkingCopyFromEnvLocal ¶
func (cmd LocalWorkingCopy) MakeLocalWorkingCopyFromEnvLocal( envLocal env_local.Env, ) (local *local_working_copy.Repo)
MakeLocalWorkingCopyFromEnvLocal preserves the legacy single-env shape for callers that already hold an env_local.Env they want to reuse. The same env is passed to both Make slots; for own scope it's correct, and for madder scope it relies on the existing dodder env_dir.GetXDGForBlobStores bridge mapping blob-store XDG to "madder". Once the dodder env_dir fork is dropped, this helper must be deleted (#151 bucket B Stage B follow-up): there will no longer be a bridge, and the second env must be a properly madder- scoped env_local.
func (LocalWorkingCopy) MakeLocalWorkingCopyWithOptions ¶
func (cmd LocalWorkingCopy) MakeLocalWorkingCopyWithOptions( req command.Request, envOptions env_ui.Options, repoOptions local_working_copy.Options, ) *local_working_copy.Repo
func (*LocalWorkingCopy) SetFlagDefinitions ¶
func (cmd *LocalWorkingCopy) SetFlagDefinitions( f interfaces.CLIFlagDefinitions, )
type LocalWorkingCopyWithQueryGroup ¶
type LocalWorkingCopyWithQueryGroup struct {
LocalWorkingCopy
Query
}
func (LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroup ¶
func (cmd LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroup( req command.Request, builderOptions queries.BuilderOption, ) (*local_working_copy.Repo, *queries.Query)
func (LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroupResolvingFilenames ¶
func (cmd LocalWorkingCopyWithQueryGroup) MakeLocalWorkingCopyAndQueryGroupResolvingFilenames( req command.Request, builderOptions queries.BuilderOption, ) (*local_working_copy.Repo, *queries.Query)
func (*LocalWorkingCopyWithQueryGroup) SetFlagDefinitions ¶
func (cmd *LocalWorkingCopyWithQueryGroup) SetFlagDefinitions(f interfaces.CLIFlagDefinitions)
type ObjectMetadata ¶
type ObjectMetadata struct{}
func (ObjectMetadata) GetFlagValueMetadataDescription ¶
func (cmd ObjectMetadata) GetFlagValueMetadataDescription( metadata objects.MetadataMutable, ) interfaces.FlagValue
func (ObjectMetadata) GetFlagValueMetadataTags ¶
func (cmd ObjectMetadata) GetFlagValueMetadataTags( metadata objects.MetadataMutable, ) interfaces.FlagValue
func (ObjectMetadata) GetFlagValueMetadataType ¶
func (cmd ObjectMetadata) GetFlagValueMetadataType( metadata objects.MetadataMutable, ) interfaces.FlagValue
type Query ¶
type Query struct {
sku.ExternalQueryOptions
}
func (Query) MakeQuery ¶
func (Query) MakeQueryIncludingWorkspace ¶
func (cmd Query) MakeQueryIncludingWorkspace( req command.Request, options pkg_query.BuilderOption, repo *local_working_copy.Repo, args []string, ) (query *pkg_query.Query)
func (Query) MakeQueryResolvingFilenames ¶
func (cmd Query) MakeQueryResolvingFilenames( req command.Request, options pkg_query.BuilderOption, repo *local_working_copy.Repo, args []string, ) (query *pkg_query.Query)
func (*Query) SetFlagDefinitions ¶
func (cmd *Query) SetFlagDefinitions(flagSet interfaces.CLIFlagDefinitions)
type Remote ¶
type Remote struct {
RemoteRepoBlobs
InventoryLists
LocalWorkingCopy
DirectPath string
RemoteConnectionType remote_connection_types.Type
// contains filtered or unexported fields
}
func (Remote) MakeDirectRemoteFromPath ¶
func (Remote) MakeHomeRepoRemote ¶
func (Remote) MakeRemote ¶
func (cmd Remote) MakeRemote( req command.Request, repo *local_working_copy.Repo, object *sku.Transacted, ) (remote repo.Repo)
returns a ready-to-use repo.Repo FROM an associated *sku.Transacted
func (Remote) MakeRemoteAndObject ¶
func (cmd Remote) MakeRemoteAndObject( req command.Request, local *local_working_copy.Repo, ) (remote repo.Repo, remoteObject *sku.Transacted)
returns a ready-to-use repo.Repo and an associated *sku.Transacted that can be persisted
func (Remote) MakeRemoteFromBlob ¶
func (cmd Remote) MakeRemoteFromBlob( req command.Request, repo *local_working_copy.Repo, blob repo_blobs.Blob, ) (remote repo.Repo)
returns a ready-to-use repo.Repo FROM an associated repo_blobs.Blob
func (Remote) MakeRemoteFromBlobAndSetPublicKey ¶
func (cmd Remote) MakeRemoteFromBlobAndSetPublicKey( req command.Request, repo *local_working_copy.Repo, blob repo_blobs.BlobMutable, ) (remote repo.Repo)
func (*Remote) MakeRemoteHTTPFromXDGDotenvPath ¶
func (*Remote) MakeRemoteStdioLocal ¶
func (*Remote) MakeRemoteStdioSSH ¶
func (*Remote) MakeRemoteUrl ¶
func (*Remote) ResolveImplicitDirectPath ¶
func (cmd *Remote) ResolveImplicitDirectPath( local *local_working_copy.Repo, )
func (*Remote) SetFlagDefinitions ¶
func (cmd *Remote) SetFlagDefinitions( flagSet interfaces.CLIFlagDefinitions, )
type RemoteRepoBlobs ¶
type RemoteRepoBlobs struct {
EnvRepo
}
func (RemoteRepoBlobs) CreateRemoteBlob ¶
func (cmd RemoteRepoBlobs) CreateRemoteBlob( req command.Request, local *local_working_copy.Repo, remoteType ids.Type, ) (blob repo_blobs.BlobMutable)
Returns a repo_blobs.BlobMutable that can be used to create a repo.Repo. The blob's public key SHOULD be set before writing it to the store.
func (*RemoteRepoBlobs) SetFlagDefinitions ¶
func (cmd *RemoteRepoBlobs) SetFlagDefinitions( flagSet interfaces.CLIFlagDefinitions, )
type RemoteTransfer ¶
type RemoteTransfer struct {
Remote
repo.ImporterOptions
}
func (*RemoteTransfer) SetFlagDefinitions ¶
func (cmd *RemoteTransfer) SetFlagDefinitions( flagDefinitions interfaces.CLIFlagDefinitions, )
Source Files
¶
- blob_store.go
- checkout.go
- complete.go
- env.go
- env_repo.go
- genesis.go
- inventory_lists.go
- local_working_copy.go
- local_working_copy_with_query_group.go
- object_metadata.go
- query.go
- remote.go
- remote_repo_blobs.go
- remote_transfer.go